<?php

/**
 * @file
 * Contains \Drupal\indeed_search\Form\IndeedSearchSettingsForm.
 */

namespace Drupal\indeed_search\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Presents the module settings form.
 */
class IndeedSearchSettingsForm extends ConfigFormBase {

/**
 * {@inheritdoc}
 */
public function getFormId() {
    return 'indeed_search_admin_settings';
  }

/**
 * {@inheritdoc}
 */
protected function getEditableConfigNames() {
    return ['indeed_search.settings'];
  }


/**
 * {@inheritdoc}
 */
public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('indeed_search.settings');
	
    $form['indeed_pubid'] = array(
    '#type' => 'textfield',
    '#title' => t('Indeed Publisher ID'),
    '#default_value' => $config->get('indeed_pubid','7681429865724784'),
    '#required' => TRUE,
  );
  
  $form['indeed_q'] = array(
    '#type' => 'textfield',
    '#title' => t('Query'),
    '#default_value' => $config->get('indeed_q'),
    '#required' => TRUE,
  );
  
  $form['indeed_l'] = array(
    '#type' => 'textfield',
    '#title' => t('Location'),
    '#default_value' => $config->get('indeed_l'),
  );
  
  $form['indeed_radius'] = array(
    '#type' => 'textfield',
    '#title' => t('Radius'),
    '#default_value' => $config->get('indeed_radius'),
    '#rules' => array('rule' => 'numeric', 'error' => 'Must be a number'),
    '#required' => TRUE,
  );

  $form['indeed_limit'] = array(
    '#type' => 'textfield',
    '#title' => t('Limit'),
    '#default_value' => $config->get('indeed_limit'),
    '#required' => TRUE,
  );
  
  $form['indeed_sort'] = array(
    '#type' => 'select',
    '#title' => 'Sort by',
    '#options' => array('relevance' => t('Relevance'),
                        'date' => t('Date'),
                  ),
    '#default_value' => $config->get('indeed_sort'),
  );
  
  $form['indeed_country'] = array(
    '#type' => 'select',
    '#title' => 'Country',
    '#options' => array('us' => t('United States'),
                        'ar' => t('Argentina'),
                        'au' => t('Australia'),
                        'at' => t('Austria'),
                        'bh' => t('Bahrain'),
                        'be' => t('Belgium'),
                        'br' => t('Brazil'),
                        'ca' => t('Canada'),
                        'cl' => t('Chile'),
                        'cn' => t('China'),
                        'co' => t('Colombia'),
                        'cz' => t('Czech Republic'),
                        'dk' => t('Denmark'),
                        'fi' => t('Finland'),
                        'fr' => t('France'),
                        'de' => t('Germany'),
                        'gr' => t('Greece'),
                        'hk' => t('Hong Kong'),
                        'hu' => t('Hungary'),
                        'in' => t('India'),
                        'id' => t('Indonesia'),
                        'ie' => t('Ireland'),
                        'il' => t('Israel'),
                        'it' => t('Italy'),
                        'jp' => t('Japan'),
                        'kr' => t('Korea'),
                        'kw' => t('Kuwait'),
                        'lu' => t('Luxembourg'),
                        'my' => t('Malaysia'),
                        'mx' => t('Mexico'),
                        'nl' => t('Netherlands'),
                        'nz' => t('New Zealand'),
                        'no' => t('Norway'),
                        'om' => t('Oman'),
                        'pk' => t('Pakistan'),
                        'pe' => t('Peru'),
                        'ph' => t('Philippines'),
                        'pl' => t('Poland'),
                        'pt' => t('Portugal'),
                        'qa' => t('Qatar'),
                        'ro' => t('Romania'),
                        'ru' => t('Russia'),
                        'sa' => t('Saudi Arabia'),
                        'sg' => t('Singapore'),
                        'za' => t('South Africa'),
                        'es' => t('Spain'),
                        'se' => t('Sweden'),
                        'ch' => t('Switzerland'),
                        'tw' => t('Taiwan'),
                        'tr' => t('Turkey'),
                        'ae' => t('United Arab Emirates'),
                        'gb' => t('United Kingdom'),
                        've' => t('Venezuela'),
                  ),
    '#default_value' => $config->get('indeed_country'),
  );

  return parent::buildForm($form, $form_state);

}

/**
 * {@inheritdoc}
 */
 
public function submitForm(array &$form, FormStateInterface $form_state) 
{
    $this->config('indeed_search.settings')
        ->set('indeed_pubid', $form_state->getValue('indeed_pubid'))
        ->set('indeed_q', $form_state->getValue('indeed_q'))
        ->set('indeed_l', $form_state->getValue('indeed_l'))
        ->set('indeed_radius', $form_state->getValue('indeed_radius'))
	->set('indeed_limit', $form_state->getValue('indeed_limit'))
	->set('indeed_sort', $form_state->getValue('indeed_sort'))
	->set('indeed_country', $form_state->getValue('indeed_country'))
        ->save();

    parent::submitForm($form, $form_state);
  }

}
	
	







